@@ -1,4 +1,4 @@
-# This code is part of Perl distribution Mail-Box-POP3 version 3.008.
+# This code is part of Perl distribution Mail-Box-POP3 version 4.000.
 # The POD got stripped from this file by OODoc version 3.05.
 # For contributors see file ChangeLog.
 
@@ -8,20 +8,18 @@
 # the same terms as the Perl 5 programming language system itself.
 # SPDX-License-Identifier: Artistic-1.0-Perl OR GPL-1.0-or-later
 
-#oodist: *** DO NOT USE THIS VERSION FOR PRODUCTION ***
-#oodist: This file contains OODoc-style documentation which will get stripped
-#oodist: during its release in the distribution.  You can use this file for
-#oodist: testing, however the code of this development version may be broken!
 
 package Mail::Box::POP3s;{
-our $VERSION = '3.008';
+our $VERSION = '4.000';
 }
 
-use base 'Mail::Box::POP3';
+use parent 'Mail::Box::POP3';
 
 use strict;
 use warnings;
 
+use Log::Report  'mail-box-pop3';
+
 #--------------------
 
 sub init($)
